NAME

PDF::Make::Builder::Shape::Pie - Pie (arc wedge) shape for PDF::Make

SYNOPSIS

$builder->add_shape(pie => {
    fill_colour => '#36f',
    x           => 200,
    y           => 300,
    r           => 80,
    rx          => 0,
    ry          => 90,
});

DESCRIPTION

Draws a filled pie wedge (arc sector) on the current page canvas, useful for pie charts. The arc runs from angle rx to ry (in degrees).

PROPERTIES

fill_colour (Str, default '#000')

Fill colour as a hex string.

x (Num, required)

Centre X coordinate.

y (Num, required)

Centre Y coordinate (bottom-left origin).

r (Num, required)

Radius in points.

rx (Num, required)

Start angle in degrees.

ry (Num, required)

End angle in degrees.

METHODS

add($builder)

Renders the pie wedge onto the current page canvas. Returns $self.

SEE ALSO

PDF::Make::Builder, PDF::Make::Builder::Shape::Circle